@@ -78,12 +78,6 @@ class base_binder(object):
         self.has_default = f_args != None and self.real_view_function.__defaults__!=None and arg_index >= len(f_args) - len(self.real_view_function.__defaults__)
         self.default = self.real_view_function.__defaults__[arg_index - (len(f_args) - len(self.real_view_function.__defaults__))] if self.has_default else None
 
-        if self.deserializer is None and self.type is not None:
-            self.deserializer = type_deserializers.get_default_deserializer(self.type)
-
-        if self.validator is None and self.type is not None:
-            self.validator = validators.get_type_validators(self.type)
-
         async def return_value(*args, **kwargs):
             args = self.framework_adapter.set_request_args(args)
             kwargs = self.framework_adapter.set_request_kwargs(kwargs)
@@ -319,7 +313,7 @@ class from_query_string(base_binder):
 _key_clean_regex=re.compile('[^a-zA-Z0-9]+')
 class from_Oauth(base_binder):
     __name__ = "from_Oauth"
-    def __init__(self, framework_adapter, allowed_domains=None, validate_options=None, client_id=None, field=None, valid_tokens=None, deserializer=None):
+    def __init__(self, framework_adapter, allowed_domains=None, validate_options=None, client_id=None, audience=None, field=None, valid_tokens=None, deserializer=None):
         """
         This function is to be used as a decorator:
         it will fill the parameter of a method by parsing the
@@ -353,6 +347,7 @@ class from_Oauth(base_binder):
         self.client_id = client_id
         self.validate_options = validate_options
         self.valid_tokens = valid_tokens or {}
+        self.audience = audience
 
 
     async def get_value(self):
@@ -397,7 +392,7 @@ class from_Oauth(base_binder):
             decoded = jwt.decode(
                 id_token,
                 key=self._public_keys[cleaned_key_id],
-                audience=self.client_id,
+                audience=self.audience,
                 options=self.validate_options)
         except Exception as ex:
             raise ForbiddenException("""You are not authorized to access the requested resource or operation.
@@ -444,7 +439,7 @@ async def _on_request_binding(decorator, *args, **kwargs):
 
     kwargs.pop(decorator.field,None)
     kwargs[decorator.field] = value
-    
+
     return await await_if_needed(decorator.func(*args, **kwargs))
 
 async def _get_dict_from_json_body(framework_adapter):
